@@ -16,6 +16,7 @@
 #endif
 
 #include "sunone-component.h"
+#include "shell/e-component-view.h"
 
 #include <unistd.h>
 #include <string.h>
@@ -86,17 +87,15 @@ finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static void
-impl_createControls (PortableServer_Servant servant,
-		     Bonobo_Control *sidebar_control,
-		     Bonobo_Control *view_control,
-		     Bonobo_Control *statusbar_control,
-		     CORBA_Environment *ev)
+static GNOME_Evolution_ComponentView
+impl_createView (PortableServer_Servant servant,
+			GNOME_Evolution_ShellView parent,
+			CORBA_Environment *ev)
 {
 	SunOneComponent *component = SUNONE_COMPONENT (bonobo_object_from_servant (servant));
 	SunOneComponentPrivate *priv = component->priv;
 	SunOneBackendView *view;
-	BonoboControl *control = NULL;
+	EComponentView *component_view;
 
 	d(printf("createControls...\n"));
 
@@ -104,18 +103,13 @@ impl_createControls (PortableServer_Servant servant,
 	if (view)
 		priv->views = g_slist_append (priv->views, view);
 
-	control = sunone_backend_view_get_sidebar (view);
-	*sidebar_control =
-		CORBA_Object_duplicate (BONOBO_OBJREF (control), ev);
-
-	control = sunone_backend_view_get_statusbar (view);
-	*statusbar_control =
-		CORBA_Object_duplicate (BONOBO_OBJREF (control), ev);
-
-	control = sunone_backend_view_get_view (view);
-	*view_control =
-		CORBA_Object_duplicate (BONOBO_OBJREF (control), ev);
+	component_view = e_component_view_new_controls (parent, 
+			"JESCS", 
+			sunone_backend_view_get_sidebar (view),
+			sunone_backend_view_get_view (view),
+			sunone_backend_view_get_statusbar (view));
 
+	return BONOBO_OBJREF (component_view);
 }
 
 static void
@@ -218,7 +212,7 @@ sunone_component_class_init (SunOneComponentClass *klass)
 	object_class->dispose = dispose;
 	object_class->finalize = finalize;
 
-	epv->createControls     = impl_createControls;
+	epv->createView 	= impl_createView;
 	epv->upgradeFromVersion = impl_upgradeFromVersion;
 	epv->requestQuit        = impl_requestQuit;
 	epv->quit               = impl_quit;
