@@ -345,10 +345,6 @@ add_sources (SunOneAccount *account, SunOneConnectionPreferences *prefs)
 		}
 #endif
 	}
-
-	e_source_list_sync (source_list_cal, NULL);
-	e_source_list_sync (source_list_task, NULL);
-
 }
 
 void
@@ -377,9 +373,6 @@ rename_source (SunOneAccount *account, const char *calid, const char *display_na
 	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "tasks");
 	rename_esource (account, display_name, physical_uri, &source_list_task);
 	g_free (physical_uri);
-
-	e_source_list_sync (source_list_cal, NULL);
-	e_source_list_sync (source_list_task, NULL);
 }
 
 
@@ -424,7 +417,6 @@ change_account (EAccountList *account_list, EAccount *account)
 		 * add.
 		 */
 		add_account (account_list, account);
-		return;
 	} else  {
 		g_object_unref (sunone_account);
 		if (!is_active_sunone_account (account)) {
@@ -438,7 +430,7 @@ change_account (EAccountList *account_list, EAccount *account)
 	}
 
 	e_notice (NULL, GTK_MESSAGE_WARNING,
-		  _("Changes to Sun JESCS account configuration will "
+		  _("Some changes to Sun JESCS account configuration will "
 		    "take\nplace after you quit and restart Evolution."));
 	return;
 
@@ -452,12 +444,10 @@ remove_account (EAccountList *account_list, EAccount *account)
 
 	sunone_account =  sunone_component_get_account_from_name (global_sunone_component, account->name);
 
-	g_return_if_fail (sunone_account);
+	/* It might not be a sunone account */
+	if (!sunone_account)
+		return;
 
-	/* Remove ESources */
-	remove_source (sunone_account, sunone_account_get_user (sunone_account), TRUE);
-	sunone_folder_tree_sync ();
-	
 	g_signal_emit (config_listener,
 		       signals[SUNONE_ACCOUNT_REMOVED], 0,
 		       sunone_account);
